<?php
/**
 * Breadcrumb Widget
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */

/**
 * Makes a custom Widget for Displaying Breadcrumb
 *
 * Learn more: http://codex.wordpress.org/Widgets_API#Developing_Widgets
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */
class rock_star_promotion_breadcrumb_widget extends WP_Widget {

	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $defaults;

	function __construct() {

		$this->defaults = array(
			'breadcrumb_on_homepage' => 0,
			'breadcrumb_seperator'          => '&raquo;',
		);

		$widget_ops = array(
			'classname'   => 'ct-breadcrumb ct-breadcrumb',
			'description' => esc_html__( 'Use this widget to add Breadcrumb', 'rock-star-pro' ),
		);

		$control_ops = array(
			'id_base' => 'ct-breadcrumb',
		);

		parent::__construct(
			'ct-breadcrumb', // Base ID
			__( 'CT: Breadcrumb', 'rock-star-pro' ), // Name
			$widget_ops,
			$control_ops
		);
	}

	/**
	 * Creates the form for the widget in the back-end which includes the Title , adcode, code, alt
	 * $instance Current settings
	 */
	function form($instance) {
		//* Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );
		?>

        <p>
            <input class="checkbox" type="checkbox" <?php checked($instance['breadcrumb_on_homepage'], true) ?> id="<?php echo $this->get_field_id( 'breadcrumb_on_homepage' ); ?>" name="<?php echo $this->get_field_name( 'breadcrumb_on_homepage' ); ?>" />
        	<label for="<?php echo $this->get_field_id('breadcrumb_on_homepage'); ?>"><?php esc_html_e( 'Check to enable Breadcrumb in Homepage', 'rock-star-pro' ); ?></label><br />
        </p>

 		<p>
            <label for="<?php echo $this->get_field_id( 'breadcrumb_seperator' ); ?>"><?php esc_html_e( 'Separator:','rock-star-pro'); ?></label>
        	<input type="text" name="<?php echo $this->get_field_name( 'breadcrumb_seperator' ); ?>" value="<?php echo esc_attr( $instance['breadcrumb_seperator'] ); ?>" class="widefat" id="<?php echo $this->get_field_id( 'breadcrumb_seperator' ); ?>" />
        </p>

        <?php
	}

	/**
	 * update the particular instant
	 *
	 * This function should check that $new_instance is set correctly.
	 * The newly calculated value of $instance should be returned.
	 * If "false" is returned, the instance won't be saved/updated.
	 *
	 * $new_instance New settings for this instance as input by the user via form()
	 * $old_instance Old settings for this instance
	 * Settings to save or bool false to cancel saving
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$instance['breadcrumb_on_homepage'] = rock_star_sanitize_checkbox( $new_instance['breadcrumb_on_homepage'] );
		$instance['breadcrumb_seperator']   = sanitize_text_field( $new_instance['breadcrumb_seperator'] );

		return $instance;
	}

	/**
	 * Displays the Widget in the front-end.
	 *
	 * $args Display arguments including before_title, after_title, before_widget, and after_widget.
	 * $instance The settings for the particular instance of the widget
	 */
	function widget( $args, $instance ) {
		// Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		$delimiter = '<span class="sep">'. $instance['breadcrumb_seperator'] .'</span><!-- .sep -->'; // delimiter between crumbs

		echo rock_star_custom_breadcrumbs( $instance['breadcrumb_on_homepage'], $delimiter );
	}

}

/**
 * Initialize Widget
 */
function rock_star_promotion_breadcrumb_init() {
	register_widget( 'rock_star_promotion_breadcrumb_widget' );
}
add_action( 'widgets_init', 'rock_star_promotion_breadcrumb_init' );
