<?php
/**
 * Featured Page Widget
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */

/**
 * Widget that shows selected page content and the title.
 * Construct the widget.
 * i.e. Name, description and control options.
 * Has form to ask the title, select page
 * In the display function we show the title and selected page's content.
 * If the title is not set, it shows the page title as the title.
 *
 */
class rock_star_get_page_widget extends WP_Widget {

	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $defaults;

	function __construct() {
		$this->defaults = array(
			'title'				=> '',
			'page_id'			=> '',
			'layout'			=> 'one-column',
			'disable_image'		=> 0,
			'image_alignment'	=> 'left',
			'image_size'		=> 'rock-star-small',
			'disable_title'		=> 0,
			'content_type'		=> 'excerpt',
			'content_limit'		=> 200,
			'background-image'	=> '',
			'more_text'			=> esc_html__( 'Read More ...', 'rock-star-pro' ),
		);

		$widget_ops = array(
			'classname'   => 'ct-featured-page ctfeaturedpostpageimage',
			'description' => esc_html__( 'Displays featured page with thumbnails', 'rock-star-pro' ),
		);

		$control_ops = array(
			'id_base' => 'ct-featured-page',
		);

		parent::__construct(
			'ct-featured-page', // Base ID
			__( 'CT: Featured Pages', 'rock-star-pro' ), // Name
			$widget_ops,
			$control_ops
		);
	}

 	function form( $instance ) {
 		//Defaults
 		$instance = wp_parse_args( (array) $instance, $this->defaults );
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title', 'rock-star-pro' ); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat" />
		</p>

        <p>
			<label for="<?php echo $this->get_field_id( 'page_id' ); ?>"><?php esc_html_e( 'Page ID', 'rock-star-pro' ); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'page_id' ); ?>" name="<?php echo $this->get_field_name( 'page_id' ); ?>" value="<?php echo sanitize_text_field( $instance['page_id'] ); ?>" class="widefat"/>
			<span class="ct-description"><?php esc_html_e( 'Separate Multiple Page IDs by ,(comma)', 'rock-star-pro' ); ?></span>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'layout' ); ?>"><?php esc_html_e( 'Layout', 'rock-star-pro' ); ?>:</label>
			<select id="<?php echo $this->get_field_id( 'layout' ); ?>" name="<?php echo $this->get_field_name( 'layout' ); ?>" class="widefat">
				<?php
					$post_type_choices = array(
						'one-column'	=> esc_html__( '1 Column', 'rock-star-pro' ),
						'two-columns'	=> esc_html__( '2 Columns', 'rock-star-pro' ),
						'three-columns'	=> esc_html__( '3 Columns', 'rock-star-pro' ),
						'four-columns'	=> esc_html__( '4 Columns', 'rock-star-pro' ),
						'five-columns'	=> esc_html__( '5 Columns', 'rock-star-pro' ),
					);

				foreach ( $post_type_choices as $key => $value ) {
					echo '<option value="' . $key . '" '. selected( $key, $instance['layout'], false ) .'>' . $value .'</option>';
				}
				?>
			</select>
		</p>

		<p>
        	<input class="checkbox ct_feat_post_disable_image" type="checkbox" <?php checked($instance['disable_image'], true) ?> id="<?php echo $this->get_field_id( 'disable_image' ); ?>" name="<?php echo $this->get_field_name( 'disable_image' ); ?>" />
        	<label for="<?php echo $this->get_field_id('disable_image'); ?>"><?php _e( 'Check to Disable Image', 'rock-star-pro' ); ?></label><br />
        </p>

        <p <?php echo ( $instance['disable_image'] )? $style : '';  ?>>
			<label for="<?php echo $this->get_field_id( 'image_alignment' ); ?>"><?php _e( 'Image Alignment', 'rock-star-pro' ); ?>:</label>
			<select id="<?php echo $this->get_field_id( 'image_alignment' ); ?>" name="<?php echo $this->get_field_name( 'image_alignment' ); ?>" class="widefat">
				<?php
					$image_alignment_choices = array(
						'top'    => __( 'Top', 'rock-star-pro' ),
						'left'   => __( 'Left', 'rock-star-pro' ),
						'right'  => __( 'Right', 'rock-star-pro' ),
						'center' => __( 'Center', 'rock-star-pro' ),
					);

				foreach ( $image_alignment_choices as $key => $value ) {
					echo '<option value="' . $key . '" '. selected( $key, $instance['image_alignment'], false ) .'>' . $value .'</option>';
				}
				?>
			</select>
		</p>

		<p <?php echo ( $instance['disable_image'] )? $style : '';  ?>>
			<label for="<?php echo $this->get_field_id( 'image_size' ); ?>"><?php _e( 'Image Size', 'rock-star-pro' ); ?>:</label>
			<select id="<?php echo $this->get_field_id( 'image_size' ); ?>" class="rock-star-image-size-selector" name="<?php echo $this->get_field_name( 'image_size' ); ?>">
				<option value="thumbnail">thumbnail (<?php echo get_option( 'thumbnail_size_w' ); ?>x<?php echo get_option( 'thumbnail_size_h' ); ?>)</option>
				<?php
				$sizes = rock_star_get_additional_image_sizes();
				foreach( (array) $sizes as $name => $size )
					echo '<option value="'.esc_attr( $name ).'" '.selected( $name, $instance['image_size'], FALSE ).'>'.esc_html( $name ).' ( '.$size['width'].'x'.$size['height'].' )</option>';
				?>
			</select>
		</p>

		<p>
        	<input class="checkbox" type="checkbox" <?php checked($instance['disable_title'], true) ?> id="<?php echo $this->get_field_id( 'disable_title' ); ?>" name="<?php echo $this->get_field_name( 'disable_title' ); ?>" />
        	<label for="<?php echo $this->get_field_id('disable_title'); ?>"><?php esc_html_e( 'Check to Disable Title', 'rock-star-pro' ); ?></label><br />
        </p>

        <p>
			<label for="<?php echo $this->get_field_id( 'content_type' ); ?>"><?php esc_html_e( 'Content Type', 'rock-star-pro' ); ?>:</label>
			<select id="<?php echo $this->get_field_id( 'content_type' ); ?>" name="<?php echo $this->get_field_name( 'content_type' ); ?>">
				<option value="content" <?php selected( 'content', $instance['content_type'] ); ?>><?php esc_html_e( 'Show Content', 'rock-star-pro' ); ?></option>
				<option value="excerpt" <?php selected( 'excerpt', $instance['content_type'] ); ?>><?php esc_html_e( 'Show Excerpt', 'rock-star-pro' ); ?></option>
				<option value="content-limit" <?php selected( 'content-limit', $instance['content_type'] ); ?>><?php esc_html_e( 'Show Content Limit', 'rock-star-pro' ); ?></option>
				<option value="" <?php selected( '', $instance['content_type'] ); ?>><?php esc_html_e( 'No Content', 'rock-star-pro' ); ?></option>
			</select>
			<br />
			<label for="<?php echo $this->get_field_id( 'content_limit' ); ?>"><?php esc_html_e( 'Limit content to', 'rock-star-pro' ); ?>
				<input type="text" id="<?php echo $this->get_field_id( 'content_limit' ); ?>" name="<?php echo $this->get_field_name( 'content_limit' ); ?>" value="<?php echo esc_attr( intval( $instance['content_limit'] ) ); ?>" size="3" />
				<?php esc_html_e( 'characters', 'rock-star-pro' ); ?>
			</label>
		</p>

		<p>
            <label for="<?php echo $this->get_field_id( 'background-image' ); ?>"><?php esc_html_e( 'Background Image Url:','rock-star-pro'); ?></label>
            <br>
        	<input type="text" class="ct-upload" name="<?php echo $this->get_field_name( 'background-image' ); ?>" value="<?php echo esc_attr( $instance['background-image'] ); ?>" id="<?php echo $this->get_field_id( 'background-image' ); ?>" />
        	<button class="upload-media-button button button-primary"><?php esc_html_e( 'Upload', 'rock-star-pro' ); ?></button>
        </p>

		<p>
			<label for="<?php echo $this->get_field_id( 'more_text' ); ?>"><?php esc_html_e( 'More Text (if applicable)', 'rock-star-pro' ); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'more_text' ); ?>" name="<?php echo $this->get_field_name( 'more_text' ); ?>" value="<?php echo esc_html( $instance['more_text'] ); ?>" />
		</p>
	<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$instance['title']				= sanitize_text_field( $new_instance['title'] );
		$instance['page_id']			= sanitize_text_field( $new_instance['page_id'] );
		$instance['layout']				= sanitize_key( $new_instance['layout'] );
		$instance['disable_image']		= rock_star_sanitize_checkbox( $new_instance['disable_image'] );
		$instance['image_alignment']	= sanitize_key( $new_instance['image_alignment'] );
		$instance['image_size']			= sanitize_key( $new_instance['image_size'] );
		$instance['disable_title']		= rock_star_sanitize_checkbox( $new_instance['disable_title'] );
		$instance['content_type']		= sanitize_key( $new_instance['content_type'] );
		$instance['content_limit']		= absint( $new_instance['content_limit'] );
		$instance['background-image']	= esc_url_raw( $new_instance['background-image'] );
		$instance['more_text']			= sanitize_text_field( $new_instance['more_text'] );
		return $instance;
	}

	function widget( $args, $instance ) {
 		$output ='';

		// Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		$output = $args['before_widget'];

		// Set up the author bio
		if ( ! empty( $instance['title'] ) ) {
			$output .= $args['before_title'] . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $args['after_title'];
		}

		$query_args = array(
			'post_type'      => 'page',
			'posts_per_page' => -1
		);


		if ( '' != $instance['page_id'] ) {
			$page_id_array = explode( ',', $instance['page_id'] );
			$query_args['post__in'] = $page_id_array;
		}

		$loop = new WP_Query( $query_args );

		if ( $loop->have_posts() ) :
			$output .= '<div class="article-wrap columns ' . esc_attr( $instance['layout'] ) . ' '. $instance['image_alignment'] . ' ' . $instance['image_size'] .'">';

				while ( $loop->have_posts() ) : $loop->the_post();

					$title_attribute = the_title_attribute( 'echo=0' );

					$class = 'post-'. esc_attr( get_the_ID() ) . ' page type-page hentry';

					if ( $instance['disable_image'] || !has_post_thumbnail() ) {
						$class .= " no-featured-image";
					}

					$output .= '
					<article class="' . esc_attr( $class ) . '">';

						if ( !$instance['disable_image'] && has_post_thumbnail() ) {

							$output.= '
							<figure class="featured-image">
                                <a href="' . esc_url( get_permalink() ) . '" title="' . $title_attribute . '">' .
									get_the_post_thumbnail(
										get_the_ID(),
										$instance['image_size']
										) .'
								</a>
                            </figure><!-- .featured-image -->';
						}
						elseif ( !$instance['disable_image'] && !has_post_thumbnail() ){
							$output.= '<div class="image">
                                <a href="' . esc_url( get_permalink() ) . '" title="' . $title_attribute . '"><img class="attachment-post-thumbnail size-post-thumbnail wp-post-image" width="290" height="290" src="'.esc_url( get_template_directory_uri() ).'/images/gallery/no-featured-image-1920x800.jpg" >
								</a>
                            </div><!-- end image -->';
						}

						$output .= '<div class="entry-container">';

							if ( !$instance['disable_title'] ) {
								$output .= '<header class="entry-header"><h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" title="'. $title_attribute .'">'. get_the_title() .'</a></h2></header>';
							}

							if ( 'excerpt' == $instance['content_type'] ) {
								$output .= '<div class="entry-summary">';
								$output .= get_the_excerpt();
								$output .= '</div><!-- .entry-summary -->';
							}
							elseif ( 'content-limit' == $instance['content_type'] ) {
								$output .= '<div class="entry-summary">';
								$output .= clean_magazine_get_the_content_limit( (int) $instance['content_limit'], esc_html( $instance['more_text'] ) );
								$output .= '</div><!-- .entry-summary -->';
							}

							elseif ( 'content' == $instance['content_type'] ) {
								$output .= '<div class="entry-content">';
								$output .= get_the_content( esc_html( $instance['more_text'] ) );
								$output .= '</div><!-- .entry-content -->';
							}

						$output .= '</div><!-- .entry-container -->';

					$output .= '</article><!-- .type-page -->';

               	endwhile;

			$output .= '</div><!-- .article-wrap -->';

		endif;

		//* Restore original query
 		wp_reset_postdata();

 		$output .= $args['after_widget'];

		echo $output;

		if ( '' != $instance['background-image'] ) {
			echo '
			<style type="text/css" rel="ct-widget-css '. esc_attr( $args['widget_id'] ) .'">
				#'. esc_attr( $args['widget_id'] ) .' {
					background-image: url('. esc_url( $instance['background-image'] ) .');
					background-position: 50% 50%;
				}
			</style>'
			;
		}
 	}
}

/**
 * Initialize Widget
 */
function rock_star_get_page_init() {
	register_widget( 'rock_star_get_page_widget' );
}
add_action( 'widgets_init', 'rock_star_get_page_init' );
