<?php
/**
 * News Ticker Widget
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */

/**
 * Makes a custom Widget for Displaying About
 *
 * Learn more: http://codex.wordpress.org/Widgets_API#Developing_Widgets
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */
class rock_star_news_ticker_widget extends WP_Widget {

	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $defaults;

	function __construct() {

		$this->defaults = array(
			'news_ticker_option'            => 'homepage',
			'news_ticker_type'              => 'demo-news-ticker',
			'news_ticker_label'             => '',
			'news_ticker_transition_effect' => 'flipVert',
			'post_id'                       => '',
			'news_ticker_select_category'   => array(),
			'news_ticker_number'            => 4,
			'news_ticker_transition_length' => 4,
			'news_ticker_transition_delay'  => 1,
		);

		$widget_ops = array(
			'classname'   => 'ct-news-ticker ctnewticker',
			'description' => esc_html__( 'Use this widget to add News Ticker', 'rock-star-pro' ),
		);

		$control_ops = array(
			'id_base' => 'ct-news-ticker',
		);

		parent::__construct(
			'ct-news-ticker', // Base ID
			__( 'CT: News Ticker', 'rock-star-pro' ), // Name
			$widget_ops,
			$control_ops
		);
	}

	/**
	 * Creates the form for the widget in the back-end which includes the Title , adcode, code, alt
	 * $instance Current settings
	 */
	function form($instance) {
		//* Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		$style = 'style="display: none;"';
		?>
		<p>
            <label for="<?php echo $this->get_field_id( 'news_ticker_option' ); ?>"><?php esc_html_e( 'Enable News Ticker on','rock-star-pro'); ?></label>
        	<select class="widefat" id="<?php echo $this->get_field_id( 'news_ticker_option' ); ?>" name="<?php echo $this->get_field_name( 'news_ticker_option' ); ?>">
				<?php
					$new_ticker_enable_options = array(
						'homepage' 		=> esc_html__( 'Homepage / Frontpage', 'rock-star-pro'),
						'entire-site' 	=> esc_html__( 'Entire Site', 'rock-star-pro'),
						'disabled'		=> esc_html__( 'Disabled', 'rock-star-pro' )
					);
					foreach ( $new_ticker_enable_options as $key => $value ) {
						echo '<option value="' . $key . '" '. selected( $key, $instance['news_ticker_option'], false ) .'>' . $value .'</option>';
					}
				?>
			</select>
        </p>

        <p>
			<label for="<?php echo $this->get_field_id( 'news_ticker_type' ); ?>"><?php esc_html_e( 'Select Ticker Type', 'rock-star-pro' ); ?>:</label>
			<select class="ct_feat_post_post_type widefat" id="<?php echo $this->get_field_id( 'news_ticker_type' ); ?>" name="<?php echo $this->get_field_name( 'news_ticker_type' ); ?>">
				<?php
					$post_type_choices = array(
						'demo-news-ticker' => esc_html__( 'Demo Content', 'rock-star-pro' ),
						'select-category'  => esc_html__( 'Select Category', 'rock-star-pro' ),
						'post-ticker'      => esc_html__( 'Post ticker', 'rock-star-pro' ),
						'page-ticker'      => esc_html__( 'Page ticker', 'rock-star-pro' ),
						'text-news-ticker' => esc_html__( 'Custom Text News Ticker', 'rock-star-pro' )
					);

				foreach ( $post_type_choices as $key => $value ) {
					echo '<option value="' . $key . '" '. selected( $key, $instance['news_ticker_type'], false ) .'>' . $value .'</option>';
				}
				?>
			</select>
			<span class="description"><?php esc_html_e( 'Please save the widget once No. of items is changed to reflect the changes', 'rock-star-pro' ); ?></span>
		</p>

        <p>
            <label for="<?php echo $this->get_field_id( 'news_ticker_transition_effect' ); ?>"><?php esc_html_e( 'Transition Effect','rock-star-pro'); ?></label>
        	<select class="widefat" id="<?php echo $this->get_field_id( 'news_ticker_transition_effect' ); ?>" name="<?php echo $this->get_field_name( 'news_ticker_transition_effect' ); ?>">
				<?php
					$news_ticker_transition_effects = array(
						'fade' 		=> esc_html__( 'Fade', 'rock-star-pro' ),
						'fadeout' 	=> esc_html__( 'Fade Out', 'rock-star-pro' ),
						'none' 		=> esc_html__( 'None', 'rock-star-pro' ),
						'scrollHorz'=> esc_html__( 'Scroll Horizontal', 'rock-star-pro' ),
						'scrollVert'=> esc_html__( 'Scroll Vertical', 'rock-star-pro' ),
						'flipHorz'	=> esc_html__( 'Flip Horizontal', 'rock-star-pro' ),
						'flipVert'	=> esc_html__( 'Flip Vertical', 'rock-star-pro' ),
						'tileSlide'	=> esc_html__( 'Tile Slide', 'rock-star-pro' ),
						'tileBlind'	=> esc_html__( 'Tile Blind', 'rock-star-pro' ),
						'shuffle'	=> esc_html__( 'Shuffle', 'rock-star-pro' )
					);
					foreach ( $news_ticker_transition_effects as $key => $value ) {
						echo '<option value="' . $key . '" '. selected( $key, $instance['news_ticker_transition_effect'], false ) .'>' . $value .'</option>';
					}
				?>
			</select>
        </p>

        <p <?php echo ( 'demo-news-ticker' != $instance['news_ticker_type'] )? '' : $style;  ?>>
            <label for="<?php echo $this->get_field_id( 'news_ticker_label' ); ?>"><?php esc_html_e( 'News Ticker Label:','rock-star-pro'); ?></label>
        	<input class="widefat" type="text" name="<?php echo $this->get_field_name( 'news_ticker_label' ); ?>" value="<?php echo esc_attr( $instance['news_ticker_label'] ); ?>" id="<?php echo $this->get_field_id( 'news_ticker_label' ); ?>" />
        </p>

        <p <?php echo ( 'post-ticker' == $instance['news_ticker_type'] )? '' : $style;  ?>>
			<label for="<?php echo $this->get_field_id( 'post_id' ); ?>"><?php esc_html_e( 'Post ID', 'rock-star-pro' ); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'post_id' ); ?>" name="<?php echo $this->get_field_name( 'post_id' ); ?>" value="<?php echo sanitize_text_field( $instance['post_id'] ); ?>" class="widefat"/>
			<span class="description"><?php esc_html_e( 'Separate Multiple Post IDs by ,(comma)', 'rock-star-pro' ); ?></span>
		</p>

		<p <?php echo ( 'page-ticker' == $instance['news_ticker_type'] )? '' : $style;  ?>>
			<label for="<?php echo $this->get_field_id( 'page_id' ); ?>"><?php esc_html_e( 'Page ID', 'rock-star-pro' ); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'page_id' ); ?>" name="<?php echo $this->get_field_name( 'page_id' ); ?>" value="<?php echo sanitize_text_field( $instance['page_id'] ); ?>" class="widefat"/>
			<span class="description"><?php esc_html_e( 'Separate Multiple Page IDs by ,(comma)', 'rock-star-pro' ); ?></span>
		</p>

        <p <?php echo ( 'select-category' == $instance['news_ticker_type'] )? '': $style; ?>>
        	<?php
        		rock_star_dropdown_categories(
        			$this->get_field_name( 'news_ticker_select_category[]' ),
        			$this->get_field_id( 'news_ticker_select_category' ),
        			(array) $instance['news_ticker_select_category']
        		);
        	?>
        </p>

        <p <?php echo ( 'id' == $instance['news_ticker_type'] )? $style : '';  ?>>
			<label for="<?php echo $this->get_field_id( 'news_ticker_number' ); ?>"><?php esc_html_e( 'No. of Posts', 'rock-star-pro' ); ?>:</label>
			<input type="number" id="<?php echo $this->get_field_id( 'news_ticker_number' ); ?>" name="<?php echo $this->get_field_name( 'news_ticker_number' ); ?>" value="<?php echo absint( $instance['news_ticker_number'] ); ?>" class="small-text" min="1" />
			<br>
			<span class="description"><?php esc_html_e( 'Please save the widget once No. of items is changed to reflect the changes', 'rock-star-pro' ); ?></span>
		</p>

		<p <?php echo ( 'id' == $instance['news_ticker_type'] )? $style : '';  ?>>
			<label for="<?php echo $this->get_field_id( 'news_ticker_transition_length' ); ?>"><?php esc_html_e( 'Transition Length', 'rock-star-pro' ); ?>:</label>
			<input type="number" id="<?php echo $this->get_field_id( 'news_ticker_transition_length' ); ?>" name="<?php echo $this->get_field_name( 'news_ticker_transition_length' ); ?>" value="<?php echo absint( $instance['news_ticker_transition_length'] ); ?>" class="small-text" min="1" />
			<br>
		</p>

		<p <?php echo ( 'id' == $instance['news_ticker_type'] )? $style : '';  ?>>
			<label for="<?php echo $this->get_field_id( 'news_ticker_transition_delay' ); ?>"><?php esc_html_e( 'Transition Delay', 'rock-star-pro' ); ?>:</label>
			<input type="number" id="<?php echo $this->get_field_id( 'news_ticker_transition_delay' ); ?>" name="<?php echo $this->get_field_name( 'news_ticker_transition_delay' ); ?>" value="<?php echo absint( $instance['news_ticker_transition_delay'] ); ?>" class="small-text" min="1" />
			<br>
		</p>

        <?php for( $i=1; $i<= absint( $instance['news_ticker_number'] ); $i++ ) {

			$link     =  isset( $instance['news_ticker_link' . '_' .  $i] ) ? $instance['news_ticker_link' . '_' . $i] : '';
			$target      =  isset( $instance['news_ticker_target' . '_' .  $i] ) ? $instance['news_ticker_target' . '_' . $i] : '';
			$title     =  isset( $instance['news_ticker_title' . '_' .  $i] ) ? $instance['news_ticker_title' . '_' . $i] : '';
		?>

        <div class="ct-image-box" <?php echo ( 'text-news-ticker' != $instance['news_ticker_type'] )? $style : '' ;  ?>>

	        <h2> <?php printf( esc_html__( 'Text News Ticker %1s', 'rock-star-pro' ), $i ); ?> </h2>

	        <p>
				<label for="<?php echo $this->get_field_id('news_ticker_title' . '_' .  $i ); ?>"><?php esc_html_e( 'Title', 'rock-star-pro' ); ?>:</label>
				<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'news_ticker_title' . '_' .  $i ); ?>" name="<?php echo $this->get_field_name('news_ticker_title' . '_' .  $i ); ?>" value="<?php echo esc_attr( $title ); ?>" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'news_ticker_link'. '_' .  $i ); ?>"><?php esc_html_e( 'Link', 'rock-star-pro' ); ?>:</label>
				<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'news_ticker_link'. '_' .  $i ); ?>" name="<?php echo $this->get_field_name( 'news_ticker_link'. '_' .  $i ); ?>" value="<?php echo esc_attr( $link ); ?>" />
			</p>

			<p>
	            <input class="checkbox" type="checkbox" <?php if( isset( $target ) && 'on' == $target ) echo 'checked="checked"'; ?> id="<?php echo $this->get_field_id( 'news_ticker_target'. '_' .  $i ); ?>" name="<?php echo $this->get_field_name( 'news_ticker_target'. '_' .  $i ); ?>" />
	        	<label for="<?php echo $this->get_field_id( 'news_ticker_target'. '_' .  $i ); ?>"><?php esc_html_e( 'Check to Open Link in New Window/Tab', 'rock-star-pro' ); ?></label><br />
	        </p>

        </div>

    	<?php } //end for ?>

        <?php
	}

	/**
	 * update the particular instant
	 *
	 * This function should check that $new_instance is set correctly.
	 * The newly calculated value of $instance should be returned.
	 * If "false" is returned, the instance won't be saved/updated.
	 *
	 * $new_instance New settings for this instance as input by the user via form()
	 * $old_instance Old settings for this instance
	 * Settings to save or bool false to cancel saving
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$i =  1;
		$j =  1;

		$instance['news_ticker_option']            = sanitize_key( $new_instance['news_ticker_option'] );
		$instance['news_ticker_type']              = sanitize_key( $new_instance['news_ticker_type'] );
		$instance['news_ticker_label']             = sanitize_text_field( $new_instance['news_ticker_label'] );
		$instance['news_ticker_transition_effect'] = sanitize_text_field( $new_instance['news_ticker_transition_effect'] );
		$instance['news_ticker_number']            = absint( $new_instance['news_ticker_number'] );
		$instance['news_ticker_transition_length'] = absint( $new_instance['news_ticker_transition_length'] );
		$instance['news_ticker_transition_delay']  = absint( $new_instance['news_ticker_transition_delay'] );

		if( 'post-ticker' == $instance['news_ticker_type'] ) {
			$instance['post_id']        = sanitize_text_field( $new_instance['post_id'] );
			$post_ids = explode( ',', $instance['post_id'] );
			foreach($post_ids as $post_id) {
				$instance['news_ticker_post_' . $i] = trim( $post_id );
				$i++;
			}
		}

		if( 'page-ticker' == $instance['news_ticker_type'] ) {
			$instance['page_id']        = sanitize_text_field( $new_instance['page_id'] );
			$page_ids = explode( ',', $instance['page_id'] );
			foreach($page_ids as $page_id) {
				$instance['news_ticker_page_' . $j] = trim( $page_id );
				$j++;
			}
		}
		$instance['news_ticker_select_category']       = ( array ) $new_instance['news_ticker_select_category'];
		$instance['post_number']    = absint( $new_instance['post_number'] );

		if( 'text-news-ticker' == $instance['news_ticker_type'] ) {
			for( $i=1; $i<= absint( $instance['news_ticker_number'] ); $i++ ) {
				$instance['news_ticker_link' . '_' .  $i] = esc_url_raw( $new_instance['news_ticker_link' . '_' .  $i] );
				$instance['news_ticker_target' . '_' .  $i] = rock_star_sanitize_checkbox( $new_instance['news_ticker_target' . '_' .  $i] );
				$instance['news_ticker_title' . '_' .  $i] = sanitize_text_field( $new_instance['news_ticker_title' . '_' .  $i] );
			}
		}



		return $instance;
	}

	/**
	 * Displays the Widget in the front-end.
	 *
	 * $args Display arguments including before_title, after_title, before_widget, and after_widget.
	 * $instance The settings for the particular instance of the widget
	 */
	function widget( $args, $instance ) {
		global $post, $wp_query;
		// Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		$enablecontent 	= $instance['news_ticker_option'];
		$contentselect 	= $instance['news_ticker_type'];

		$headline = $instance['news_ticker_label'];

		// Front page displays in Reading Settings
		$page_on_front 	= get_option('page_on_front');
		$page_for_posts = get_option('page_for_posts');

		$page_id = $wp_query->get_queried_object_id();
		if ( 'entire-site' == $enablecontent  || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enablecontent  ) ) {

			echo $args['before_widget'];

			echo '<!-- refreshing cache -->';


			if ( 'demo-news-ticker' == $contentselect  ) {
				$headline 		= esc_html__( 'The Latest News', 'rock-star-pro' );
			}

			$news_ticker ='
				<div id="news-ticker" class="' . esc_attr( $contentselect ) . '">
					<div class="wrapper">';
						if ( !empty( $headline ) ) {
							$news_ticker .='<h2 class="news-ticker-label">' . wp_kses_post( $headline ) . '</h2>';
						}
						$news_ticker .='

						<div class="new-ticket-content">
							<div class="news-ticker-slider cycle-slideshow"
							    data-cycle-log="false"
							    data-cycle-pause-on-hover="true"
							    data-cycle-swipe="true"
							    data-cycle-auto-height=container
								data-cycle-slides="> h2"
								 data-cycle-speed="'. esc_attr( $instance['news_ticker_transition_length'] ) * 1000 .'"
							    data-cycle-timeout="'. esc_attr( $instance['news_ticker_transition_delay'] ) * 1000 .'"
								data-cycle-slides="> h2"
								data-cycle-fx="'. esc_attr( $instance['news_ticker_transition_effect'] ) .'"
								>';

								// Select content
								if ( 'demo-news-ticker' == $contentselect  && function_exists( 'rock_star_demo_ticker' ) ) {
									$news_ticker .= rock_star_demo_ticker( $instance );
								}
								elseif ( 'post-ticker' == $contentselect  && function_exists( 'rock_star_post_ticker' ) ) {
									$news_ticker .= rock_star_post_ticker( $instance );
								}
								elseif ( 'page-ticker' == $contentselect  && function_exists( 'rock_star_page_ticker' ) ) {
									$news_ticker .= rock_star_page_ticker( $instance );
								}
								elseif ( 'select-category' == $contentselect  && function_exists( 'rock_star_category_ticker' ) ) {
									$news_ticker .= rock_star_category_ticker( $instance );
								}
								elseif ( 'text-news-ticker' == $contentselect  && function_exists( 'rock_star_text_ticker' ) ) {
									$news_ticker .= rock_star_text_ticker( $instance );
								}

				$news_ticker .='
							</div><!-- .news-ticker-slider -->
						</div><!-- .new-ticket-content -->
					</div><!-- .wrapper -->
				</div><!-- #news-ticker -->';

				echo $news_ticker;

			echo $args['after_widget'];
		}

	}

}

/**
 * Initialize Widget
 */
function rock_star_news_ticker_init() {
	register_widget( 'rock_star_news_ticker_widget' );
}
add_action( 'widgets_init', 'rock_star_news_ticker_init' );
